@@ -16,17 +16,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-permission-manager.c,v 1.10 2004/11/02 20:56:55 chpe Exp $
+ *  $Id: ephy-permission-manager.c,v 1.12 2005/01/06 18:14:41 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-permission-manager.h"
+#include "ephy-embed-type-builtins.h"
 #include "ephy-marshal.h"
 #include "ephy-debug.h"
 
-/* EphyPermissionInfo */
-
 GType
 ephy_permission_info_get_type (void)
 {
