@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.21 2004/12/18 21:51:47 chpe Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.22 2005/01/28 22:23:38 chpe Exp $
  */
 
 /*
@@ -71,12 +71,12 @@
 
 GtkNSSKeyPairDialogs::GtkNSSKeyPairDialogs ()
 {
-	LOG ("GtkNSSKeyPairDialogs ctor (%p)", this)
+	LOG ("GtkNSSKeyPairDialogs ctor (%p)", this);
 }
 
 GtkNSSKeyPairDialogs::~GtkNSSKeyPairDialogs ()
 {
-	LOG ("GtkNSSKeyPairDialogs dtor (%p)", this)
+	LOG ("GtkNSSKeyPairDialogs dtor (%p)", this);
 }
 
 NS_IMPL_ISUPPORTS1 (GtkNSSKeyPairDialogs, 
