@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.55 2004/12/19 00:10:38 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.65 2005/02/28 22:07:57 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -60,6 +60,10 @@
 #define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
 #undef MOZILLA_STRICT_API
+#include <nsMemory.h>
+
+#include <errno.h>
+#include <stdlib.h>
 
 const char* const persistContractID = "@mozilla.org/embedding/browser/nsWebBrowserPersist;1";
 
@@ -69,17 +73,21 @@ MozDownload::MozDownload() :
 	mEmbedPersist(nsnull),
 	mDownloadState(EPHY_DOWNLOAD_INITIALISING)
 {
-	LOG ("MozDownload ctor (%p)", (void *) this)
+	LOG ("MozDownload ctor (%p)", (void *) this);
 }
 
 MozDownload::~MozDownload()
 {
-	LOG ("MozDownload dtor (%p)", (void *) this)
+	LOG ("MozDownload dtor (%p)", (void *) this);
 
 	NS_ASSERTION (!mEphyDownload, "MozillaDownload still alive!");
 }
 
-NS_IMPL_ISUPPORTS3(MozDownload, nsIDownload, nsITransfer, nsIWebProgressListener)
+#ifdef HAVE_NSITRANSFER_H
+NS_IMPL_ISUPPORTS2(MozDownload, nsIWebProgressListener, nsITransfer)
+#else
+NS_IMPL_ISUPPORTS3(MozDownload, nsIWebProgressListener, nsIDownload, nsITransfer)
+#endif
 
 NS_IMETHODIMP
 MozDownload::InitForEmbed (nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayName,
@@ -100,11 +108,11 @@ MozDownload::Init(nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayNam
 
 	if (mEmbedPersist)
 	{
-		EmbedPersistFlags flags;
+		EphyEmbedPersistFlags flags;
 
 		flags = ephy_embed_persist_get_flags (EPHY_EMBED_PERSIST (mEmbedPersist));
 
-		addToView = !(flags & EMBED_PERSIST_NO_VIEW);
+		addToView = !(flags & EPHY_EMBED_PERSIST_NO_VIEW);
 	}
 
 	mSource = aSource;
@@ -151,6 +159,7 @@ MozDownload::GetSource(nsIURI **aSource)
 	return NS_OK;
 }
 
+#ifndef HAVE_NSITRANSFER_H
 NS_IMETHODIMP
 MozDownload::GetTarget(nsIURI **aTarget)
 {
@@ -159,6 +168,7 @@ MozDownload::GetTarget(nsIURI **aTarget)
 
 	return NS_OK;
 }
+#endif
 
 NS_IMETHODIMP
 MozDownload::GetTargetFile (nsILocalFile** aTargetFile)
@@ -175,6 +185,7 @@ MozDownload::GetTargetFile (nsILocalFile** aTargetFile)
 	return rv;
 }
 
+#ifndef HAVE_NSITRANSFER_H
 NS_IMETHODIMP
 MozDownload::GetPersist(nsIWebBrowserPersist **aPersist)
 {
@@ -183,6 +194,7 @@ MozDownload::GetPersist(nsIWebBrowserPersist **aPersist)
 
 	return NS_OK;
 }
+#endif
 
 NS_IMETHODIMP
 MozDownload::GetPercentComplete(PRInt32 *aPercentComplete)
@@ -193,6 +205,7 @@ MozDownload::GetPercentComplete(PRInt32 *aPercentComplete)
  	return NS_OK;
 }
 
+#ifndef HAVE_NSITRANSFER_H
 #ifdef MOZ_NSIDOWNLOAD_GETSIZE
 /* readonly attribute PRUint64 amountTransferred; */
 NS_IMETHODIMP
@@ -207,7 +220,30 @@ MozDownload::GetSize(PRUint64 *aSize)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
-#endif /* MOZ_NSIDOWNLOAD_GETSIZE */
+
+#endif  /* MOZ_NSIDOWNLOAD_GETSIZE */
+
+NS_IMETHODIMP
+MozDownload::GetStartTime(PRInt64 *aStartTime)
+{
+	NS_ENSURE_ARG_POINTER(aStartTime);
+	*aStartTime = mStartTime;
+
+	return NS_OK;
+}
+
+NS_IMETHODIMP
+MozDownload::GetDisplayName(PRUnichar * *aDisplayName)
+{
+	return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+NS_IMETHODIMP
+MozDownload::SetDisplayName(const PRUnichar * aDisplayName)
+{
+	return NS_ERROR_NOT_IMPLEMENTED;
+}
+#endif /* !HAVE_NSITRANSFER_H */
 
 NS_IMETHODIMP
 MozDownload::GetTotalProgress(PRInt32 *aTotalProgress)
@@ -236,27 +272,6 @@ MozDownload::GetState(EphyDownloadState *aDownloadState)
 	return NS_OK;
 }
 
-NS_IMETHODIMP
-MozDownload::GetDisplayName(PRUnichar * *aDisplayName)
-{
-	return NS_ERROR_NOT_IMPLEMENTED;
-}
-
-NS_IMETHODIMP
-MozDownload::SetDisplayName(const PRUnichar * aDisplayName)
-{
-	return NS_ERROR_NOT_IMPLEMENTED;
-}
-
-NS_IMETHODIMP
-MozDownload::GetStartTime(PRInt64 *aStartTime)
-{
-	NS_ENSURE_ARG_POINTER(aStartTime);
-	*aStartTime = mStartTime;
-
-	return NS_OK;
-}
-
 NS_IMETHODIMP
 MozDownload::GetElapsedTime(PRInt64 *aElapsedTime)
 {
@@ -312,7 +327,7 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 	if (NS_FAILED(aStatus) && NS_SUCCEEDED(mStatus))
         	mStatus = aStatus;
 
-	if (aStateFlags & STATE_START)
+	if (aStateFlags & EPHY_EMBED_STATE_START)
 	{
 		mDownloadState = EPHY_DOWNLOAD_DOWNLOADING;
 
@@ -323,10 +338,10 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 	}
 
 	/* We will get this even in the event of a cancel */
-	if (aStateFlags & STATE_STOP)
+	if (aStateFlags & EPHY_EMBED_STATE_STOP)
 	{
 		/* Keep us alive */
-		nsCOMPtr<nsIDownload> kungFuDeathGrip(this);
+		nsCOMPtr<nsITransfer> kungFuDeathGrip(this);
 
 		mDownloadState = NS_SUCCEEDED (aStatus) ? EPHY_DOWNLOAD_COMPLETED : EPHY_DOWNLOAD_FAILED;
 		if (mEphyDownload)
@@ -354,58 +369,61 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 		else if (NS_SUCCEEDED (aStatus))
 		{
 			GnomeVFSMimeApplication *helperApp;
-#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 			nsEmbedCString mimeType;
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 			rv = mMIMEInfo->GetMIMEType (mimeType);
 			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-			helperApp = gnome_vfs_mime_get_default_application (mimeType.get()); 
-
 			nsEmbedString description;
 			mMIMEInfo->GetApplicationDescription (description);
 
 			nsEmbedCString cDesc;
 			NS_UTF16ToCString (description, NS_CSTRING_ENCODING_UTF8, cDesc);
-
-			/* HACK we use the application description to decide
-			   if we have to open the saved file */
-			if ((strcmp (cDesc.get(), "gnome-default") == 0) &&
-			    helperApp)
 #else
-			char *mimeType;
-			rv = mMIMEInfo->GetMIMEType (&mimeType);
+			char *mime = nsnull;
+			rv = mMIMEInfo->GetMIMEType (&mime);
 			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-			helperApp = gnome_vfs_mime_get_default_application (mimeType); 
+			if (mime)
+			{
+				mimeType.Assign (mime);
+				nsMemory::Free (mime);
+			}
 
 			PRUnichar *description;
 			mMIMEInfo->GetApplicationDescription (&description);
+			NS_ENSURE_TRUE (description, NS_ERROR_FAILURE);
 
 			nsEmbedCString cDesc;
 			NS_UTF16ToCString (nsEmbedString(description),
 					   NS_CSTRING_ENCODING_UTF8, cDesc);
 
+			nsMemory::Free (description);
+#endif
+
 			/* HACK we use the application description to decide
 			   if we have to open the saved file */
-			if (strcmp (cDesc.get(), "gnome-default") == 0 &&
-			    helperApp)
-#endif
+			if (g_str_has_suffix (cDesc.get(), "gnome-default:"))
 			{
-				GList *params = NULL;
-				char *param;
+				/* Format gnome-default:<usertime>:<helperapp id> */
+				char **str = g_strsplit (cDesc.get(), ":", -1);
+				g_return_val_if_fail (g_strv_length (str) != 3, NS_ERROR_FAILURE);
+
+				char *end;
+				guint32 user_time = strtoul (str[1], &end, 0);
+
+				helperApp = gnome_vfs_mime_application_new_from_desktop_id (str[2]);
+				if (!helperApp) return NS_ERROR_FAILURE;
+
 				nsEmbedCString aDest;
+				rv = mDestination->GetSpec (aDest);
+				NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-				mDestination->GetSpec (aDest);
+				ephy_file_launch_application (helperApp, aDest.get (), user_time);
 
-				param = gnome_vfs_make_uri_canonical (aDest.get ());
-				params = g_list_append (params, param);
-				gnome_vfs_mime_application_launch (helperApp, params);
-				g_free (param);
-
-				g_list_free (params);
+				gnome_vfs_mime_application_free (helperApp);
+				g_strfreev (str);
 			}
-
-			gnome_vfs_mime_application_free (helperApp);
 		}
 	}
         
@@ -523,7 +541,7 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 {
 	nsresult rv = NS_OK;
 
-	EmbedPersistFlags ephy_flags;
+	EphyEmbedPersistFlags ephy_flags;
 	ephy_flags = ephy_embed_persist_get_flags (EPHY_EMBED_PERSIST (embedPersist));
 
 	PRBool isHTML = (contentType &&
@@ -554,18 +572,18 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 
 	PRInt32 flags = nsIWebBrowserPersist::PERSIST_FLAGS_REPLACE_EXISTING_FILES;
 
-	if (!domDocument && !isHTML && !(ephy_flags & EMBED_PERSIST_COPY_PAGE) &&
-	    !(ephy_flags & EMBED_PERSIST_DO_CONVERSION))
+	if (!domDocument && !isHTML && !(ephy_flags & EPHY_EMBED_PERSIST_COPY_PAGE) &&
+	    !(ephy_flags & EPHY_EMBED_PERSIST_DO_CONVERSION))
 	{
 		flags |= nsIWebBrowserPersist::PERSIST_FLAGS_NO_CONVERSION;
 	}
-	if (ephy_flags & EMBED_PERSIST_COPY_PAGE)
+	if (ephy_flags & EPHY_EMBED_PERSIST_COPY_PAGE)
 	{
 		flags |= nsIWebBrowserPersist::PERSIST_FLAGS_FROM_CACHE;
 	}
 	webPersist->SetPersistFlags(flags);
 
-	if (!domDocument || !isHTML || ephy_flags & EMBED_PERSIST_COPY_PAGE)
+	if (!domDocument || !isHTML || ephy_flags & EPHY_EMBED_PERSIST_COPY_PAGE)
 	{
 		rv = webPersist->SaveURI (sourceURI, aCacheKey, nsnull,
 					  postData, nsnull, inDestFile);
@@ -745,6 +763,8 @@ nsresult BuildDownloadPath (const char *defaultFileName, nsILocalFile **_retval)
 	}
 
 	nsCOMPtr <nsILocalFile> destFile (do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
+	NS_ENSURE_TRUE (destFile, NS_ERROR_FAILURE);
+
 	destFile->InitWithNativePath (nsEmbedCString (path));
 	g_free (path);
 
