@@ -15,12 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.h,v 1.7 2004/11/19 19:13:40 chpe Exp $
+ *  $Id: MozillaPrivate.h,v 1.8 2005/02/11 13:56:43 chpe Exp $
  */
 
 #include <glib.h>
 
+class nsIPrefBranch;
+
 namespace MozillaPrivate
 {
 	GList   *GetPrinterList ();
+
+	void	 SecureWallet (nsIPrefBranch *pref);
 }
