@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.97 2005/01/23 15:38:02 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.101 2005/01/31 13:53:05 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,6 +25,7 @@
 
 #include "mozilla-embed.h"
 #include "mozilla-embed-event.h"
+#include "ephy-embed-single.h"
 #include "ephy-embed-shell.h"
 #include "ephy-command-manager.h"
 #include "ephy-string.h"
@@ -57,15 +58,15 @@ static void mozilla_embed_net_state_all_cb	(GtkMozEmbed *embed,
 						 gint state,
 						 guint status,
 						 MozillaEmbed *membed);
-static gint mozilla_embed_dom_mouse_click_cb	(GtkMozEmbed *embed,
+static gboolean mozilla_embed_dom_mouse_click_cb(GtkMozEmbed *embed,
 						 gpointer dom_event,
 						 MozillaEmbed *membed);
-static gint mozilla_embed_dom_mouse_down_cb	(GtkMozEmbed *embed,
+static gboolean mozilla_embed_dom_mouse_down_cb	(GtkMozEmbed *embed,
 						 gpointer dom_event, 
 						 MozillaEmbed *membed);
 static void mozilla_embed_new_window_cb		(GtkMozEmbed *embed, 
 						 GtkMozEmbed **newEmbed,
-						 guint chromemask,
+						 guint chrome_mask,
 						 MozillaEmbed *membed);
 static void mozilla_embed_security_change_cb	(GtkMozEmbed *embed, 
 						 gpointer request,
@@ -338,54 +339,64 @@ impl_can_go_forward (EphyEmbed *embed)
 	return gtk_moz_embed_can_go_forward (GTK_MOZ_EMBED(embed));
 }
 
-static char *
-mozilla_embed_get_uri_parent (const char *aUri)
+static gboolean
+mozilla_embed_get_uri_parent (MozillaEmbed *membed,
+			      const char *aUri,
+			      nsEmbedCString &aParent)
 {
         nsresult rv;
+	nsEmbedCString encoding;
+	rv = membed->priv->browser->GetEncoding (encoding);
+	if (NS_FAILED (rv)) return FALSE;
 
         nsCOMPtr<nsIURI> uri;
-        rv = EphyUtils::NewURI (getter_AddRefs(uri), nsEmbedCString(aUri));
-        if (NS_FAILED(rv) || !uri) return NULL;
+        rv = EphyUtils::NewURI (getter_AddRefs(uri), nsEmbedCString(aUri), encoding.get());
+        if (NS_FAILED(rv) || !uri) return FALSE;
+
+	/* Don't support going 'up' with chrome url's, mozilla handily
+	 * fixes them up for us, so it doesn't work properly, see
+	 * rdf/chrome/src/nsChromeProtocolHandler.cpp::NewURI()
+	 * (the Canonify() call)
+	 */
+	nsEmbedCString scheme;
+	rv = uri->GetScheme (scheme);
+	if (NS_FAILED(rv) || !scheme.Length()) return FALSE;
+	if (strcmp (scheme.get(), "chrome") == 0) return FALSE;
 
 	nsEmbedCString path;
 	rv = uri->GetPath(path);
-	if (NS_FAILED(rv)) return NULL;
+	if (NS_FAILED(rv) || !path.Length()) return FALSE;
+	if (strcmp (path.get (), "/") == 0) return FALSE;
 
-	if (!path.Length() || strcmp (path.get(), "/") == 0 ||
-	    !strchr (path.get(), '/'))
+	const char *slash = strrchr (path.BeginReading(), '/');
+	if (!slash) return FALSE;
+
+	if (slash[1] == '\0')
 	{
-		return NULL;
+		/* ends with a slash - a directory, go to parent */
+		rv = uri->Resolve (nsEmbedCString(".."), aParent);
+	}
+	else
+	{
+		/* it's a file, go to the directory */
+		rv = uri->Resolve (nsEmbedCString("."), aParent);
 	}
 
-	nsEmbedCString parent;
-	rv = uri->Resolve (nsEmbedCString(".."), parent);
-	if (NS_FAILED(rv)) return NULL;
-
-	return g_strdup (parent.get()); 
+	return NS_SUCCEEDED (rv);
 }
 
 static gboolean
 impl_can_go_up (EphyEmbed *embed)
 {
-	char *address, *s;
+	MozillaEmbed *membed = MOZILLA_EMBED (embed);
+	char *address;
 	gboolean result;
 
 	address = ephy_embed_get_location (embed, TRUE);
-	if (address == NULL)
-	{
-		return FALSE;
-	}
-
-	if ((s = mozilla_embed_get_uri_parent (address)) != NULL)
-	{
-		g_free (s);
-		result = TRUE;
-	}
-	else
-	{
-		result = FALSE;
-	}
+	if (address == NULL) return FALSE;
 
+	nsEmbedCString parent;
+	result = mozilla_embed_get_uri_parent (membed, address, parent);
 	g_free (address);
 
 	return result;
@@ -394,20 +405,20 @@ impl_can_go_up (EphyEmbed *embed)
 static GSList *
 impl_get_go_up_list (EphyEmbed *embed)
 {
+	MozillaEmbed *membed = MOZILLA_EMBED (embed);
 	GSList *l = NULL;
 	char *address, *s;
 
 	address = ephy_embed_get_location (embed, TRUE);
-	if (address == NULL)
-	{
-		return NULL;
-	}
-	
+	if (address == NULL) return NULL;
+
 	s = address;
-	while ((s = mozilla_embed_get_uri_parent (s)) != NULL)
+	nsEmbedCString parent;
+	while (mozilla_embed_get_uri_parent (membed, s, parent))
 	{
+		s = g_strdup (parent.get());
 		l = g_slist_prepend (l, s);
-	}				
+	}
 
 	g_free (address);
 
@@ -429,23 +440,20 @@ impl_go_forward (EphyEmbed *embed)
 static void
 impl_go_up (EphyEmbed *embed)
 {
+	MozillaEmbed *membed = MOZILLA_EMBED (embed);
 	char *uri;
-	char *parent_uri;
 
 	uri = ephy_embed_get_location (embed, TRUE);
-	if (uri == NULL)
-	{
-		return;
-	}
-	
-	parent_uri = mozilla_embed_get_uri_parent (uri);
+	if (uri == NULL) return;
+
+	gboolean rv;
+	nsEmbedCString parent_uri;
+	rv = mozilla_embed_get_uri_parent (membed, uri, parent_uri);
 	g_free (uri);
 
-	if (parent_uri)
-	{
-		ephy_embed_load_url (embed, parent_uri);
-		g_free (parent_uri);
-	}
+	g_return_if_fail (rv != FALSE);
+
+	ephy_embed_load_url (embed, parent_uri.get ());
 }
 
 static char *
@@ -864,21 +872,18 @@ mozilla_embed_net_state_all_cb (GtkMozEmbed *embed, const char *aURI,
 	g_signal_emit_by_name (membed, "ge_net_state", aURI, estate);
 }
 
-static gint
-mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed, gpointer dom_event, 
-				  MozillaEmbed *membed)
+static gboolean
+mozilla_embed_emit_mouse_signal (MozillaEmbed *embed,
+				 gpointer dom_event, 
+				 const char *signal_name)
 {
+	MozillaEmbedPrivate *mpriv = embed->priv;
 	MozillaEmbedEvent *info;
 	EventContext event_context;
 	gint return_value = FALSE;
 	nsresult rv;
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 
-	if (dom_event == NULL)
-	{
-		g_warning ("mozilla_embed_dom_mouse_click_cb: domevent NULL");
-		return FALSE;
-	}
+	if (dom_event == NULL) return FALSE;
 
 	nsCOMPtr<nsIDOMMouseEvent> ev = static_cast<nsIDOMMouseEvent*>(dom_event);
 	NS_ENSURE_TRUE (ev, FALSE);
@@ -889,65 +894,20 @@ mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed, gpointer dom_event,
 
 	event_context.Init (mpriv->browser);
         rv = event_context.GetMouseEventInfo (ev, MOZILLA_EMBED_EVENT (info));
-
-	if (NS_SUCCEEDED (rv))
+	if (NS_FAILED (rv))
 	{
-		nsCOMPtr<nsIDOMDocument> domDoc;
-		rv = event_context.GetTargetDocument (getter_AddRefs(domDoc));
-		if (NS_SUCCEEDED (rv))
-		{
-			rv = mpriv->browser->PushTargetDocument (domDoc);
-			if (NS_SUCCEEDED (rv))
-			{
-				g_signal_emit_by_name (membed, "ge_dom_mouse_click", 
-						       info, &return_value); 
-				mpriv->browser->PopTargetDocument ();
-			}
-		}
-
-	}
-
-	g_object_unref (info);
-
-	return return_value;
-}
-
-static gint
-mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event, 
-				 MozillaEmbed *membed)
-{
-	MozillaEmbedEvent *info;
-	EventContext event_context;
-	gint return_value = FALSE;
-	nsresult rv;
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-
-	if (dom_event == NULL)
-	{
-		g_warning ("mozilla_embed_dom_mouse_down_cb: domevent NULL");
+		g_object_unref (info);
 		return FALSE;
 	}
 
-	nsCOMPtr<nsIDOMMouseEvent> ev = static_cast<nsIDOMMouseEvent*>(dom_event);
-	NS_ENSURE_TRUE (ev, FALSE);
-	nsCOMPtr<nsIDOMEvent> dev = do_QueryInterface (ev);
-	NS_ENSURE_TRUE (dev, FALSE);
-
-	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, dev));
-
-	event_context.Init (mpriv->browser);
-        rv = event_context.GetMouseEventInfo (ev, MOZILLA_EMBED_EVENT (info));
-	if (NS_FAILED (rv)) return FALSE;
-
 	nsCOMPtr<nsIDOMDocument> domDoc;
 	rv = event_context.GetTargetDocument (getter_AddRefs(domDoc));
 	if (NS_SUCCEEDED (rv))
 	{
 		mpriv->browser->PushTargetDocument (domDoc);
 
-		g_signal_emit_by_name (membed, "ge_dom_mouse_down", 
+		g_signal_emit_by_name (embed, signal_name, 
 				       info, &return_value); 
-
 		mpriv->browser->PopTargetDocument ();
 	}
 
@@ -956,20 +916,30 @@ mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event,
 	return return_value;
 }
 
-static void
-mozilla_embed_new_window_cb (GtkMozEmbed *embed, 
-			     GtkMozEmbed **newEmbed,
-                             guint chrome_mask, 
-			     MozillaEmbed *membed)
+static gboolean
+mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed,
+				  gpointer dom_event, 
+				  MozillaEmbed *membed)
 {
-	guint i;
-	guint mask = 0;
-	EphyEmbed *new_embed = NULL;
+	return mozilla_embed_emit_mouse_signal (membed, dom_event,
+						"ge_dom_mouse_click");
+}
 
-	struct
+static gboolean
+mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event, 
+				 MozillaEmbed *membed)
+{
+	return mozilla_embed_emit_mouse_signal (membed, dom_event,
+						"ge_dom_mouse_down");
+}
+
+EphyEmbedChrome
+_mozilla_embed_translate_chrome (GtkMozEmbedChromeFlags flags)
+{
+	static const struct
 	{
-		guint mozilla_mask;
-		guint embed_mask;
+		guint mozilla_flag;
+		guint ephy_flag;
 	}
 	conversion_map [] =
 	{
@@ -977,28 +947,49 @@ mozilla_embed_new_window_cb (GtkMozEmbed *embed,
 		{ GTK_MOZ_EMBED_FLAG_TOOLBARON, EPHY_EMBED_CHROME_TOOLBAR },
 		{ GTK_MOZ_EMBED_FLAG_STATUSBARON, EPHY_EMBED_CHROME_STATUSBAR },
 		{ GTK_MOZ_EMBED_FLAG_PERSONALTOOLBARON, EPHY_EMBED_CHROME_BOOKMARKSBAR },
-		{ 0, 0 }
 	};
 
-	if (chrome_mask & GTK_MOZ_EMBED_FLAG_OPENASCHROME)
+	guint mask = 0, i;
+
+	for (i = 0; i < G_N_ELEMENTS (conversion_map); i++)
+	{
+		if (flags & conversion_map[i].mozilla_flag)
+		{
+			mask |= conversion_map[i].ephy_flag;
+		}
+	}
+
+	return (EphyEmbedChrome) mask;
+}
+
+static void
+mozilla_embed_new_window_cb (GtkMozEmbed *embed, 
+			     GtkMozEmbed **newEmbed,
+			     guint chrome_mask, 
+			     MozillaEmbed *membed)
+{
+	GtkMozEmbedChromeFlags chrome = (GtkMozEmbedChromeFlags) chrome_mask;
+	EphyEmbed *new_embed = NULL;
+	GObject *single;
+	EphyEmbedChrome mask;
+
+	if (chrome & GTK_MOZ_EMBED_FLAG_OPENASCHROME)
 	{
 		*newEmbed = _mozilla_embed_new_xul_dialog ();
 		return;
 	}
 
-	for (i = 0; conversion_map[i].mozilla_mask != 0; i++)
-	{
-		if (chrome_mask & conversion_map[i].mozilla_mask)
-		{
-			mask |= conversion_map[i].embed_mask;
-		}
-	}
+	mask = _mozilla_embed_translate_chrome (chrome);
 
-	g_signal_emit_by_name (membed, "ge_new_window", mask, &new_embed);
+	single = ephy_embed_shell_get_embed_single (embed_shell);
+	g_signal_emit_by_name (single, "new-window", embed, mask,
+			       &new_embed);
 
 	g_assert (new_embed != NULL);
 
-	gtk_moz_embed_set_chrome_mask (GTK_MOZ_EMBED (new_embed), chrome_mask);
+	gtk_moz_embed_set_chrome_mask (GTK_MOZ_EMBED (new_embed), chrome);
+
+	g_signal_emit_by_name (membed, "ge-new-window", new_embed);
 
 	*newEmbed = GTK_MOZ_EMBED (new_embed);
 }
@@ -1113,6 +1104,17 @@ xul_new_window_cb (GtkMozEmbed *embed,
         *retval = _mozilla_embed_new_xul_dialog ();
 }
 
+static void
+xul_title_cb (GtkMozEmbed *embed,
+	      GtkWindow *window)
+{
+	char *title;
+
+	title = gtk_moz_embed_get_title (embed);
+	gtk_window_set_title (window, title);
+	g_free (title);
+}
+
 GtkMozEmbed *
 _mozilla_embed_new_xul_dialog (void)
 {
@@ -1135,6 +1137,9 @@ _mozilla_embed_new_xul_dialog (void)
 	g_signal_connect_object (embed, "new_window",
 				 G_CALLBACK (xul_new_window_cb),
 				 NULL, (GConnectFlags) 0);
+	g_signal_connect_object (embed, "title",
+				 G_CALLBACK (xul_title_cb),
+				 window, (GConnectFlags) 0);
 
 	return GTK_MOZ_EMBED (embed);
 }
