@@ -194,7 +194,56 @@ ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (../../lib/ephy-marshal.list:4) */
+/* BOOLEAN:STRING,STRING,STRING (../../lib/ephy-marshal.list:4) */
+extern void ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
+                                                        GValue       *return_value,
+                                                        guint         n_param_values,
+                                                        const GValue *param_values,
+                                                        gpointer      invocation_hint,
+                                                        gpointer      marshal_data);
+void
+ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
+                                            GValue       *return_value,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint,
+                                            gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_STRING_STRING) (gpointer     data1,
+                                                                  gpointer     arg_1,
+                                                                  gpointer     arg_2,
+                                                                  gpointer     arg_3,
+                                                                  gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING_STRING_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_string (param_values + 2),
+                       g_marshal_value_peek_string (param_values + 3),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:VOID (../../lib/ephy-marshal.list:5) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -237,31 +286,32 @@ ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:FLAGS (../../lib/ephy-marshal.list:5) */
-extern void ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
-                                        GValue       *return_value,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint,
-                                        gpointer      marshal_data);
+/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
 void
-ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
-                            GValue       *return_value,
-                            guint         n_param_values,
-                            const GValue *param_values,
-                            gpointer      invocation_hint,
-                            gpointer      marshal_data)
+ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data)
 {
-  typedef GObject* (*GMarshalFunc_OBJECT__FLAGS) (gpointer     data1,
-                                                  guint        arg_1,
-                                                  gpointer     data2);
-  register GMarshalFunc_OBJECT__FLAGS callback;
+  typedef GObject* (*GMarshalFunc_OBJECT__OBJECT_FLAGS) (gpointer     data1,
+                                                         gpointer     arg_1,
+                                                         guint        arg_2,
+                                                         gpointer     data2);
+  register GMarshalFunc_OBJECT__OBJECT_FLAGS callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
-  g_return_if_fail (n_param_values == 2);
+  g_return_if_fail (n_param_values == 3);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -273,16 +323,17 @@ ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_OBJECT__FLAGS) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_OBJECT__OBJECT_FLAGS) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
-                       g_marshal_value_peek_flags (param_values + 1),
+                       g_marshal_value_peek_object (param_values + 1),
+                       g_marshal_value_peek_flags (param_values + 2),
                        data2);
 
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:7) */
 extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -331,7 +382,7 @@ ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* STRING:VOID (../../lib/ephy-marshal.list:7) */
+/* STRING:VOID (../../lib/ephy-marshal.list:8) */
 extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -374,10 +425,10 @@ ephy_marshal_STRING__VOID (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:ENUM (../../lib/ephy-marshal.list:8) */
+/* VOID:ENUM (../../lib/ephy-marshal.list:9) */
 #define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -420,7 +471,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:11) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -463,7 +514,7 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:11) */
+/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -506,7 +557,7 @@ ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (../../lib/ephy-marshal.list:12) */
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -549,7 +600,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
