@@ -30,7 +30,15 @@ extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* BOOLEAN:VOID (../../lib/ephy-marshal.list:4) */
+/* BOOLEAN:STRING,STRING,STRING (../../lib/ephy-marshal.list:4) */
+extern void ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
+                                                        GValue       *return_value,
+                                                        guint         n_param_values,
+                                                        const GValue *param_values,
+                                                        gpointer      invocation_hint,
+                                                        gpointer      marshal_data);
+
+/* BOOLEAN:VOID (../../lib/ephy-marshal.list:5) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -38,15 +46,15 @@ extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* OBJECT:FLAGS (../../lib/ephy-marshal.list:5) */
-extern void ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
-                                        GValue       *return_value,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint,
-                                        gpointer      marshal_data);
+/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
 
-/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:7) */
 extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -54,7 +62,7 @@ extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* STRING:VOID (../../lib/ephy-marshal.list:7) */
+/* STRING:VOID (../../lib/ephy-marshal.list:8) */
 extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -62,10 +70,10 @@ extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:ENUM (../../lib/ephy-marshal.list:8) */
+/* VOID:ENUM (../../lib/ephy-marshal.list:9) */
 #define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -73,7 +81,7 @@ extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:11) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -81,7 +89,7 @@ extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:11) */
+/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -89,7 +97,7 @@ extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,INT (../../lib/ephy-marshal.list:12) */
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -97,7 +105,7 @@ extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
