@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.c,v 1.18 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-node-db.c,v 1.21 2005/01/28 22:24:03 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-node-db.h"
 #include "ephy-file-helpers.h"
@@ -50,7 +48,7 @@ enum
 
 #define EPHY_NODE_DB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_DB, EphyNodeDbPrivate))
 
-struct EphyNodeDbPrivate
+struct _EphyNodeDbPrivate
 {
 	char *name;
 	gboolean immutable;
@@ -253,7 +251,7 @@ node_from_id_real (EphyNodeDb *db, guint id)
 	EphyNode *ret = NULL;
 
 	if (id < db->priv->id_to_node->len)
-		ret = g_ptr_array_index (db->priv->id_to_node, id);;
+		ret = g_ptr_array_index (db->priv->id_to_node, id);
 
 	return ret;
 }
@@ -382,7 +380,7 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 	gboolean was_immutable;
 	int ret;
 
-	LOG ("ephy_node_db_load_from_file %s", xml_file)
+	LOG ("ephy_node_db_load_from_file %s", xml_file);
 
 	START_PROFILER ("loading node db")
 
@@ -470,7 +468,7 @@ ephy_node_db_write_to_xml_valist (EphyNodeDb *db,
 	EphyNode *node;
 	int ret;
 
-	LOG ("Saving node db to %s", filename)
+	LOG ("Saving node db to %s", filename);
 
 	START_PROFILER ("Saving node db")
 
