@@ -22,7 +22,7 @@
  *
  * This is the header file for the throbber on the location bar
  *
- * $Id: ephy-spinner.h,v 1.9 2004/07/02 22:05:59 chpe Exp $
+ * $Id: ephy-spinner.h,v 1.10 2005/01/08 19:41:47 chpe Exp $
  */
 
 #ifndef EPHY_SPINNER_H
@@ -40,11 +40,11 @@ G_BEGIN_DECLS
 #define EPHY_IS_SPINNER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_SPINNER))
 #define EPHY_SPINNER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_SPINNER, EphySpinnerClass))
 
-typedef struct EphySpinner		EphySpinner;
-typedef struct EphySpinnerClass		EphySpinnerClass;
-typedef struct EphySpinnerDetails	EphySpinnerDetails;
+typedef struct _EphySpinner		EphySpinner;
+typedef struct _EphySpinnerClass		EphySpinnerClass;
+typedef struct _EphySpinnerDetails	EphySpinnerDetails;
 
-struct EphySpinner
+struct _EphySpinner
 {
 	GtkEventBox parent;
 
@@ -52,7 +52,7 @@ struct EphySpinner
 	EphySpinnerDetails *details;
 };
 
-struct EphySpinnerClass
+struct _EphySpinnerClass
 {
 	GtkEventBoxClass parent_class;
 };
