@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tree-model-sort.h,v 1.4 2003/11/19 19:19:53 chpe Exp $
+ *  $Id: ephy-tree-model-sort.h,v 1.6 2005/01/21 19:33:02 jbaayen Exp $
  */
 
 #ifndef EPHY_TREE_MODEL_SORT_H
@@ -33,7 +33,7 @@ G_BEGIN_DECLS
 #define EPHY_IS_TREE_MODEL_SORT_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_TREE_MODEL_SORT))
 #define EPHY_TREE_MODEL_SORT_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSortClass))
 
-typedef struct EphyTreeModelSortPrivate EphyTreeModelSortPrivate;
+typedef struct _EphyTreeModelSortPrivate EphyTreeModelSortPrivate;
 
 typedef struct
 {
@@ -50,12 +50,14 @@ typedef struct
 	void (*node_from_iter) (EphyTreeModelSort *model, GtkTreeIter *iter, void **node);
 } EphyTreeModelSortClass;
 
-GType		ephy_tree_model_sort_get_type		(void);
+GType		ephy_tree_model_sort_get_type		      (void);
 
-GtkTreeModel   *ephy_tree_model_sort_new		(GtkTreeModel *child_model);
+GtkTreeModel   *ephy_tree_model_sort_new		      (GtkTreeModel *child_model);
 
-void		ephy_tree_model_sort_set_column_id	(EphyTreeModelSort *ms,
-							 int id);
+void		ephy_tree_model_sort_set_base_drag_column_id  (EphyTreeModelSort *ms,
+							       int id);
+void		ephy_tree_model_sort_set_extra_drag_column_id (EphyTreeModelSort *ms,
+							       int id);
 
 G_END_DECLS
 
