@@ -16,16 +16,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-menu.c,v 1.39 2004/12/13 19:00:24 chpe Exp $
+ *  $Id: ephy-bookmarks-menu.c,v 1.41 2005/01/28 22:25:02 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-bookmarks-menu.h"
 #include "ephy-bookmark-action.h"
+#include "ephy-link.h"
 #include "ephy-shell.h"
 #include "ephy-node-common.h"
-#include "ephy-marshal.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 
@@ -68,6 +68,8 @@ struct _EphyBookmarksMenuPrivate
 #define FOLDER_VERB_FORMAT		"Fld%x%x"
 #define FOLDER_VERB_FORMAT_LENGTH	strlen (FOLDER_VERB_FORMAT) + 2 * MAXLEN + 1
 
+#define BMK_ACCEL_PATH_PREFIX "<Actions>/BmkActions/"
+
 #define GAZILLION	200
 #define UPDATE_DELAY	5000 /* ms */
 #define LABEL_WIDTH_CHARS	32
@@ -79,14 +81,6 @@ enum
 	PROP_UI_MANAGER
 };
 
-enum
-{
-	OPEN,
-	LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL] = { 0 };
-
 static void ephy_bookmarks_menu_class_init (EphyBookmarksMenuClass *klass);
 static void ephy_bookmarks_menu_init	   (EphyBookmarksMenu *menu);
 
@@ -111,10 +105,19 @@ ephy_bookmarks_menu_get_type (void)
                         0, /* n_preallocs */
                         (GInstanceInitFunc) ephy_bookmarks_menu_init
                 };
+		static const GInterfaceInfo link_info = 
+		{
+			NULL,
+			NULL,
+			NULL
+		};
 
                 type = g_type_register_static (G_TYPE_OBJECT,
 					       "EphyBookmarksMenu",
 					       &our_info, 0);
+		g_type_add_interface_static (type,
+					     EPHY_TYPE_LINK,
+					     &link_info);
         }
 
         return type;
@@ -183,26 +186,6 @@ ephy_bookmarks_menu_clean (EphyBookmarksMenu *menu)
 	STOP_PROFILER ("Cleaning bookmarks menu")
 }
 
-static void
-open_bookmark_cb (GtkAction *action,
-		  const char *location,
-		  EphyBookmarksMenu *menu)
-{
-	g_signal_emit (menu, signals[OPEN], 0, location,
-		       ephy_gui_is_middle_click ());
-}
-
-static void
-open_bookmark_in_tab_cb (GtkAction *action,
-			 const char *location,
-			 gboolean dummy,
-			 EphyBookmarksMenu *menu)
-{
-	g_signal_emit (menu, signals[OPEN], 0, location, TRUE);
-}
-
-#define BMK_ACCEL_PATH_PREFIX "<Actions>/BmkActions/"
-
 static void
 add_action_for_bookmark (EphyBookmarksMenu *menu,
 			 EphyNode *bmk)
@@ -223,10 +206,8 @@ add_action_for_bookmark (EphyBookmarksMenu *menu,
 
 	gtk_action_set_accel_path (action, apath);
 
-	g_signal_connect (action, "open",
-			  G_CALLBACK (open_bookmark_cb), menu);
-	g_signal_connect (action, "open_in_tab",
-			  G_CALLBACK (open_bookmark_in_tab_cb), menu);
+	g_signal_connect_swapped (action, "open-link",
+				  G_CALLBACK (ephy_link_open), menu);
 
 	gtk_action_group_add_action (menu->priv->bmk_actions, action);
 	g_object_unref (action);
@@ -452,12 +433,12 @@ ephy_bookmarks_menu_rebuild (EphyBookmarksMenu *menu)
 
 	if (menu->priv->needs_update == FALSE)
 	{
-		LOG ("No update required")
+		LOG ("No update required");
 	
 		return;
 	}
 
-	LOG ("Rebuilding bookmarks menu")
+	LOG ("Rebuilding bookmarks menu");
 
 	ephy_bookmarks_menu_clean (menu);
 
@@ -519,7 +500,7 @@ ephy_bookmarks_menu_rebuild (EphyBookmarksMenu *menu)
 static gboolean
 do_update_cb (EphyBookmarksMenu *menu)
 {
-	LOG ("do_update_cb")
+	LOG ("do_update_cb");
 
 	ephy_bookmarks_menu_rebuild (menu);
 	menu->priv->update_tag = 0;
@@ -593,7 +574,7 @@ static void
 bookmarks_tree_changed_cb (EphyBookmarks *bookmarks,
 			   EphyBookmarksMenu *menu)
 {
-	LOG ("bookmarks_tree_changed_cb")
+	LOG ("bookmarks_tree_changed_cb");
 
 	ephy_bookmarks_menu_maybe_update (menu);
 }
@@ -603,7 +584,7 @@ topics_added_cb (EphyNode *keywords,
 		 EphyNode *bmk,
 		 EphyBookmarksMenu *menu)
 {
-	LOG ("topics_added_cb")
+	LOG ("topics_added_cb");
 
 	ephy_bookmarks_menu_maybe_update (menu);
 }
@@ -614,7 +595,7 @@ topics_removed_cb (EphyNode *keywords,
 		   guint old_index,
 		   EphyBookmarksMenu *menu)
 {
-	LOG ("topics_removed_cb")
+	LOG ("topics_removed_cb");
 
 	ephy_bookmarks_menu_maybe_update (menu);
 }
@@ -626,7 +607,7 @@ topic_child_changed_cb (EphyNode *node,
 			EphyBookmarksMenu *menu)
 {
 	LOG ("topic_child_changed_cb id=%d property=%d",
-	     ephy_node_get_id (child), property_id)
+	     ephy_node_get_id (child), property_id);
 
 	if (property_id == EPHY_NODE_KEYWORD_PROP_NAME)
 	{
@@ -642,7 +623,7 @@ bookmark_added_cb (EphyNode *bookmarks,
 		   EphyNode *bmk,
 		   EphyBookmarksMenu *menu)
 {
-	LOG ("bookmark_added_cb id=%d", ephy_node_get_id (bmk))
+	LOG ("bookmark_added_cb id=%d", ephy_node_get_id (bmk));
 
 	if (menu->priv->bmk_actions != NULL)
 	{
@@ -675,7 +656,7 @@ bookmark_removed_cb (EphyNode *bookmarks,
 		     guint old_index,
 		     EphyBookmarksMenu *menu)
 {
-	LOG ("bookmark_removed_cb id=%d", ephy_node_get_id (bmk))
+	LOG ("bookmark_removed_cb id=%d", ephy_node_get_id (bmk));
 
 	if (menu->priv->bmk_actions != NULL)
 	{
@@ -694,7 +675,7 @@ static void
 activate_cb (GtkAction *action,
 	     EphyBookmarksMenu *menu)
 {
-	LOG ("activate_cb")
+	LOG ("activate_cb");
 
 	ephy_bookmarks_menu_rebuild (menu);
 }
@@ -781,7 +762,7 @@ ephy_bookmarks_menu_finalize (GObject *o)
 
 	g_free (p->path);
 
-	LOG ("EphyBookmarksMenu finalised %p", o);
+	LOG ("EphyBookmarksMenu finalised %p", o);;
 
 	G_OBJECT_CLASS (parent_class)->finalize (o);
 }
@@ -798,18 +779,6 @@ ephy_bookmarks_menu_class_init (EphyBookmarksMenuClass *klass)
 	object_class->set_property = ephy_bookmarks_menu_set_property;
 	object_class->get_property = ephy_bookmarks_menu_get_property;
 
-	signals[OPEN] =
-                g_signal_new ("open",
-                              G_OBJECT_CLASS_TYPE (object_class),
-                              G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (EphyBookmarksMenuClass, open),
-                              NULL, NULL,
-                              ephy_marshal_VOID__STRING_BOOLEAN,
-                              G_TYPE_NONE,
-                              2,
-			      G_TYPE_STRING,
-			      G_TYPE_BOOLEAN);
-
 	g_object_class_install_property (object_class,
                                          PROP_PATH,
                                          g_param_spec_string  ("path",
