@@ -16,15 +16,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.91.4.1 2004/09/27 18:11:40 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.120 2005/02/21 11:23:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-shell.h"
+#include "ephy-type-builtins.h"
 #include "ephy-embed-shell.h"
+#include "ephy-embed-single.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
 #include "ephy-file-helpers.h"
@@ -37,13 +37,19 @@
 #include "prefs-dialog.h"
 #include "ephy-debug.h"
 #include "ephy-extensions-manager.h"
-#include "toolbar.h"
 #include "ephy-session.h"
 #include "downloader-view.h"
 #include "egg-toolbars-model.h"
 #include "ephy-toolbars-model.h"
+#include "ephy-toolbar.h"
 #include "ephy-automation.h"
 #include "print-dialog.h"
+#include "ephy-prefs.h"
+#include "ephy-gui.h"
+
+#ifdef ENABLE_DBUS
+#include "ephy-dbus.h"
+#endif
 
 #include <string.h>
 #include <bonobo/bonobo-main.h>
@@ -51,16 +57,16 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmessagedialog.h>
+#include <gtk/gtknotebook.h>
 #include <dirent.h>
 #include <unistd.h>
 #include <libgnomeui/gnome-client.h>
 
 #define AUTOMATION_IID "OAFIID:GNOME_Epiphany_Automation"
-#define SERVER_TIMEOUT 60000
 
 #define EPHY_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SHELL, EphyShellPrivate))
 
-struct EphyShellPrivate
+struct _EphyShellPrivate
 {
 	BonoboGenericFactory *automation_factory;
 	EphySession *session;
@@ -68,13 +74,15 @@ struct EphyShellPrivate
 	EggToolbarsModel *toolbars_model;
 	EggToolbarsModel *fs_toolbars_model;
 	EphyExtensionsManager *extensions_manager;
+	GObject *dbus_service;
 	GtkWidget *bme;
 	GtkWidget *history_window;
 	GObject *pdm_dialog;
 	GObject *prefs_dialog;
 	GObject *print_setup_dialog;
 	GList *del_on_exit;
-	guint server_timeout;
+
+	gboolean embed_single_connected;
 };
 
 EphyShell *ephy_shell = NULL;
@@ -82,6 +90,7 @@ EphyShell *ephy_shell = NULL;
 static void ephy_shell_class_init	(EphyShellClass *klass);
 static void ephy_shell_init		(EphyShell *shell);
 static void ephy_shell_finalize		(GObject *object);
+static GObject *impl_get_embed_single   (EphyEmbedShell *embed_shell);
 
 static GObjectClass *parent_class = NULL;
 
@@ -103,7 +112,7 @@ ephy_shell_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -130,14 +139,115 @@ static void
 ephy_shell_class_init (EphyShellClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	EphyEmbedShellClass *embed_shell_class = EPHY_EMBED_SHELL_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = ephy_shell_finalize;
 
+	embed_shell_class->get_embed_single = impl_get_embed_single;
+
 	g_type_class_add_private (object_class, sizeof(EphyShellPrivate));
 }
 
+static EphyEmbed *
+ephy_shell_new_window_cb (EphyEmbedSingle *single,
+			  EphyEmbed *parent_embed,
+			  EphyEmbedChrome chromemask,
+			  EphyShell *shell)
+{
+	GtkWidget *parent = NULL;
+	EphyTab *new_tab;
+	EphyNewTabFlags flags = EPHY_NEW_TAB_DONT_SHOW_WINDOW |
+				EPHY_NEW_TAB_APPEND_LAST |
+				EPHY_NEW_TAB_IN_NEW_WINDOW |
+				EPHY_NEW_TAB_JUMP;
+
+	LOG ("ephy_shell_new_window_cb tab chrome %d", chromemask);
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME))
+	{
+		chromemask = EPHY_EMBED_CHROME_ALL;
+	}
+
+	if (parent_embed != NULL)
+	{
+		/* this will either be a EphyWindow, or the embed itself
+		 * (in case it's about to be destroyed, which means it's already
+		 * removed from its tab)
+		 */
+		parent = gtk_widget_get_toplevel (GTK_WIDGET (parent_embed));
+	}
+
+	new_tab = ephy_shell_new_tab_full
+		(shell,
+		 EPHY_IS_WINDOW (parent) ? EPHY_WINDOW (parent) : NULL,
+		 NULL, NULL, flags, chromemask, 0);
+
+	return ephy_tab_get_embed (new_tab);
+}
+
+
+static gboolean
+ephy_shell_add_sidebar_cb (EphyEmbedSingle *embed_single,
+			   const char *url,
+			   const char *title,
+			   EphyShell *shell)
+{
+	EphySession *session;
+	EphyWindow *window;
+	GtkWidget *dialog;
+
+	session = EPHY_SESSION (ephy_shell_get_session (shell));
+	g_return_val_if_fail (EPHY_IS_SESSION (session), FALSE);
+
+	window = ephy_session_get_active_window (session);
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_OK,
+					 _("Sidebar extension required"));
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Sidebar Extension Required"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		  _("The link you clicked needs the sidebar extension to be "
+		    "installed."));
+
+	g_signal_connect_swapped (dialog, "response", 
+				  G_CALLBACK (gtk_widget_destroy), dialog);
+
+	gtk_widget_show (dialog);
+
+	return TRUE;
+}
+
+static GObject*
+impl_get_embed_single (EphyEmbedShell *embed_shell)
+{
+	EphyShell *shell = EPHY_SHELL (embed_shell);
+	GObject *embed_single;
+
+	embed_single = EPHY_EMBED_SHELL_CLASS (parent_class)->get_embed_single (embed_shell);
+
+	if (embed_single != NULL && shell->priv->embed_single_connected == FALSE)
+	{
+		g_signal_connect_object (embed_single, "new-window",
+					 G_CALLBACK (ephy_shell_new_window_cb),
+					 shell, G_CONNECT_AFTER);
+
+		g_signal_connect_object (embed_single, "add-sidebar",
+					 G_CALLBACK (ephy_shell_add_sidebar_cb),
+					 shell, G_CONNECT_AFTER);
+
+		shell->priv->embed_single_connected = TRUE;
+	}
+	
+	return embed_single;
+}
+
 static BonoboObject *
 ephy_automation_factory_cb (BonoboGenericFactory *this_factory,
 			    const char *iid,
@@ -177,17 +287,6 @@ ephy_shell_init (EphyShell *shell)
 
 	shell->priv = EPHY_SHELL_GET_PRIVATE (shell);
 
-	shell->priv->session = NULL;
-	shell->priv->bookmarks = NULL;
-	shell->priv->bme = NULL;
-	shell->priv->history_window = NULL;
-	shell->priv->pdm_dialog = NULL;
-	shell->priv->print_setup_dialog = NULL;
-	shell->priv->toolbars_model = NULL;
-	shell->priv->fs_toolbars_model = NULL;
-	shell->priv->extensions_manager = NULL;
-	shell->priv->server_timeout = 0;
-
 	/* globally accessible singleton */
 	g_assert (ephy_shell == NULL);
 	ephy_shell = shell;
@@ -215,8 +314,11 @@ path_from_command_line_arg (const char *arg)
 
 static void
 open_urls (GNOME_EphyAutomation automation,
-	   const char **args, CORBA_Environment *ev,
-	   gboolean new_tab, gboolean existing_window,
+	   guint32 user_time,
+	   const char **args,
+	   CORBA_Environment *ev,
+	   gboolean new_tab,
+	   gboolean existing_window,
 	   gboolean fullscreen)
 {
 	int i;
@@ -224,9 +326,9 @@ open_urls (GNOME_EphyAutomation automation,
 	if (args == NULL)
 	{
 		/* Homepage or resume */
-		GNOME_EphyAutomation_loadurl
+		GNOME_EphyAutomation_loadUrlWithStartupId
 			(automation, "", fullscreen,
-			 existing_window, new_tab, ev);
+			 existing_window, new_tab, user_time, ev);
 	}
 	else
 	{
@@ -236,23 +338,15 @@ open_urls (GNOME_EphyAutomation automation,
 
 			path = path_from_command_line_arg (args[i]);
 
-			GNOME_EphyAutomation_loadurl
+			GNOME_EphyAutomation_loadUrlWithStartupId
 				(automation, path, fullscreen,
-				 existing_window, new_tab, ev);
+				 existing_window, new_tab, user_time, ev);
 
 			g_free (path);
 		}
 	}
 }
 
-static gboolean
-server_timeout (EphyShell *shell)
-{
-	g_object_unref (shell);
-
-	return FALSE;
-}
-
 static gboolean
 save_yourself_cb (GnomeClient *client,
 		  gint phase,
@@ -262,11 +356,13 @@ save_yourself_cb (GnomeClient *client,
 		  gboolean fast,
 		  EphyShell *shell)
 {
-	char *argv[] = { "epiphany", "--load-session", NULL };
-	char *discard_argv[] = { "rm", "-r", NULL };
+	char *argv[] = { NULL, "--load-session", NULL };
+	char *discard_argv[] = { "rm", "-f", NULL };
 	EphySession *session;
 	char *tmp, *save_to;
 
+	LOG ("save_yourself_cb");
+
 	tmp = g_build_filename (ephy_dot_dir (),
 				"session_gnome-XXXXXX",
 				NULL);
@@ -275,6 +371,7 @@ save_yourself_cb (GnomeClient *client,
 
 	session = EPHY_SESSION (ephy_shell_get_session (shell));
 
+	argv[0] = g_get_prgname ();
 	argv[2] = save_to;
 	gnome_client_set_restart_command
 		(client, 3, argv);
@@ -296,6 +393,8 @@ die_cb (GnomeClient* client,
 {
 	EphySession *session;
 
+	LOG ("die_cb");
+
 	session = EPHY_SESSION (ephy_shell_get_session (shell));
 	ephy_session_close (session);
 }
@@ -320,6 +419,7 @@ gnome_session_init (EphyShell *shell)
 gboolean
 ephy_shell_startup (EphyShell *shell,
 		    EphyShellStartupFlags flags,
+		    guint32 user_time,
 		    const char **args,
 		    const char *string_arg,
 		    GError **error)
@@ -359,13 +459,7 @@ ephy_shell_startup (EphyShell *shell,
 			g_assert_not_reached ();
 	}
 
-	if (flags & EPHY_SHELL_STARTUP_SERVER)
-	{
-		g_object_ref (shell);
-		shell->priv->server_timeout = g_timeout_add
-			(SERVER_TIMEOUT, (GSourceFunc)server_timeout, shell);
-	}
-	else if (result == Bonobo_ACTIVATION_REG_SUCCESS ||
+	if (result == Bonobo_ACTIVATION_REG_SUCCESS ||
 		 result == Bonobo_ACTIVATION_REG_ALREADY_ACTIVE)
 	{
 		automation = bonobo_activation_activate_from_id (AUTOMATION_IID,
@@ -381,13 +475,13 @@ ephy_shell_startup (EphyShell *shell,
 		}
 		else if (flags & EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR)
 		{
-			GNOME_EphyAutomation_openBookmarksEditor
-				(automation, &ev);
+			GNOME_EphyAutomation_openBookmarksEditorWithStartupId
+				(automation, user_time, &ev);
 		}
 		else if (flags & EPHY_SHELL_STARTUP_SESSION)
 		{
-			GNOME_EphyAutomation_loadSession
-				(automation, string_arg, &ev);
+			GNOME_EphyAutomation_loadSessionWithStartupId
+				(automation, string_arg, user_time, &ev);
 		}
 		else if (flags & EPHY_SHELL_STARTUP_IMPORT_BOOKMARKS)
 		{
@@ -401,7 +495,7 @@ ephy_shell_startup (EphyShell *shell,
 		}
 		else
 		{
-			open_urls (automation, args, &ev,
+			open_urls (automation, user_time, args, &ev,
 				   flags & EPHY_SHELL_STARTUP_TABS,
 				   flags & EPHY_SHELL_STARTUP_EXISTING_WINDOW,
 				   flags & EPHY_SHELL_STARTUP_FULLSCREEN);
@@ -428,25 +522,37 @@ ephy_shell_finalize (GObject *object)
 
 	g_assert (ephy_shell == NULL);
 
-	if (shell->priv->server_timeout > 0)
+	/* this will unload the extensions */
+	LOG ("Unref extension manager");
+	if (shell->priv->extensions_manager)
 	{
-		g_source_remove (shell->priv->server_timeout);
+		g_object_unref (shell->priv->extensions_manager);
 	}
 
-	/* this will unload the extensions */
-	LOG ("Unref extension manager")
-	g_object_unref (shell->priv->extensions_manager);
+#ifdef ENABLE_DBUS
+	LOG ("Shutting down DBUS service");
+	if (shell->priv->dbus_service)
+	{
+		g_object_unref (shell->priv->dbus_service);
+	}
+#endif
 
-	LOG ("Unref toolbars model")
+	LOG ("Unref session manager");
+	if (shell->priv->session)
+	{
+		g_object_unref (shell->priv->session);
+	}
+
+	LOG ("Unref toolbars model");
 	if (shell->priv->toolbars_model)
 	{
-		g_object_unref (G_OBJECT (shell->priv->toolbars_model));
+		g_object_unref (shell->priv->toolbars_model);
 	}
 
-	LOG ("Unref fullscreen toolbars model")
+	LOG ("Unref fullscreen toolbars model");
 	if (shell->priv->fs_toolbars_model)
 	{
-		g_object_unref (G_OBJECT (shell->priv->fs_toolbars_model));
+		g_object_unref (shell->priv->fs_toolbars_model);
 	}
 
 	LOG ("Unref Bookmarks Editor");
@@ -461,25 +567,25 @@ ephy_shell_finalize (GObject *object)
 		gtk_widget_destroy (GTK_WIDGET (shell->priv->history_window));
 	}
 
-	LOG ("Unref PDM Dialog")
+	LOG ("Unref PDM Dialog");
 	if (shell->priv->pdm_dialog)
 	{
 		g_object_unref (shell->priv->pdm_dialog);
 	}
 
-	LOG ("Unref prefs dialog")
+	LOG ("Unref prefs dialog");
 	if (shell->priv->prefs_dialog)
 	{
 		g_object_unref (shell->priv->prefs_dialog);
 	}
 
-	LOG ("Unref print setup dialog")
+	LOG ("Unref print setup dialog");
 	if (shell->priv->print_setup_dialog)
 	{
 		g_object_unref (shell->priv->print_setup_dialog);
 	}
 
-	LOG ("Unref bookmarks")
+	LOG ("Unref bookmarks");
 	if (shell->priv->bookmarks)
 	{
 		g_object_unref (shell->priv->bookmarks);
@@ -495,7 +601,21 @@ ephy_shell_finalize (GObject *object)
 		bonobo_object_unref (shell->priv->automation_factory);
 	}
 
-	LOG ("Ephy shell finalized")
+	LOG ("Ephy shell finalized");
+}
+
+
+/**
+ * ephy_shell_get_default:
+ *
+ * Retrieve the default #EphyShell object
+ *
+ * ReturnValue: the default #EphyShell
+ **/
+EphyShell *
+ephy_shell_get_default (void)
+{
+   return ephy_shell;
 }
 
 EphyShell *
@@ -524,23 +644,27 @@ load_homepage (EphyEmbed *embed)
 }
 
 /**
- * ephy_shell_new_tab:
+ * ephy_shell_new_tab_full:
  * @shell: a #EphyShell
  * @parent_window: the target #EphyWindow or %NULL
  * @previous_tab: the referrer tab or %NULL
  * @url: an url to load or %NULL
+ * @chrome: a #EphyEmbedChrome mask to use if creating a new window
+ * @user_time: a timestamp, or 0
  *
  * Create a new tab and the parent window when necessary.
- * Ever use this function to open urls in new window/tabs.
+ * Use this function to open urls in new window/tabs.
  *
  * ReturnValue: the created #EphyTab
  **/
 EphyTab *
-ephy_shell_new_tab (EphyShell *shell,
-		    EphyWindow *parent_window,
-		    EphyTab *previous_tab,
-		    const char *url,
-		    EphyNewTabFlags flags)
+ephy_shell_new_tab_full (EphyShell *shell,
+			 EphyWindow *parent_window,
+			 EphyTab *previous_tab,
+			 const char *url,
+			 EphyNewTabFlags flags,
+			 EphyEmbedChrome chrome,
+			 guint32 user_time)
 {
 	EphyWindow *window;
 	EphyTab *tab;
@@ -550,7 +674,7 @@ ephy_shell_new_tab (EphyShell *shell,
 	EphyEmbed *previous_embed = NULL;
 	GtkWidget *nb;
 	int position = -1;
-	Toolbar *toolbar;
+	EphyToolbar *toolbar;
 
 	if (flags & EPHY_NEW_TAB_IN_NEW_WINDOW) in_new_window = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_EXISTING_WINDOW) in_new_window = FALSE;
@@ -559,13 +683,16 @@ ephy_shell_new_tab (EphyShell *shell,
 
 	jump_to = (flags & EPHY_NEW_TAB_JUMP) != 0;
 
+	LOG ("Opening new tab parent-window %p parent-tab %p in-new-window:%s jump-to:%s",
+	     parent_window, previous_tab, in_new_window ? "t" : "f", jump_to ? "t" : "f");
+
 	if (!in_new_window && parent_window != NULL)
 	{
 		window = parent_window;
 	}
 	else
 	{
-		window = ephy_window_new ();
+		window = ephy_window_new_with_chrome (chrome);
 	}
 
 	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
@@ -587,13 +714,24 @@ ephy_shell_new_tab (EphyShell *shell,
 	embed = ephy_tab_get_embed (tab);
 
 	ephy_window_add_tab (window, tab, position, jump_to);
-	gtk_window_present (GTK_WINDOW (window));
+
+	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
+
+	if ((flags & EPHY_NEW_TAB_DONT_SHOW_WINDOW) == 0)
+	{
+		gtk_widget_show (GTK_WIDGET (window));
+	}
+
+	if (flags & EPHY_NEW_TAB_FULLSCREEN_MODE)
+	{
+		gtk_window_fullscreen (GTK_WINDOW (window));
+	}
 
 	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
 	    flags & EPHY_NEW_TAB_NEW_PAGE)
 	{
-		ephy_tab_set_location (tab, "", TAB_ADDRESS_EXPIRE_NEXT);
-		toolbar_activate_location (toolbar);
+		ephy_tab_set_location (tab, "", EPHY_TAB_ADDRESS_EXPIRE_NEXT);
+		ephy_toolbar_activate_location (toolbar);
 		load_homepage (embed);
 	}
 	else if (flags & EPHY_NEW_TAB_OPEN_PAGE)
@@ -602,14 +740,33 @@ ephy_shell_new_tab (EphyShell *shell,
 		ephy_embed_load_url (embed, url);
 	}
 
-	if (flags & EPHY_NEW_TAB_FULLSCREEN_MODE)
-	{
-		gtk_window_fullscreen (GTK_WINDOW (window));
-	}
-
 	return tab;
 }
 
+/**
+ * ephy_shell_new_tab:
+ * @shell: a #EphyShell
+ * @parent_window: the target #EphyWindow or %NULL
+ * @previous_tab: the referrer tab or %NULL
+ * @url: an url to load or %NULL
+ *
+ * Create a new tab and the parent window when necessary.
+ * Use this function to open urls in new window/tabs.
+ *
+ * ReturnValue: the created #EphyTab
+ **/
+EphyTab *
+ephy_shell_new_tab (EphyShell *shell,
+		    EphyWindow *parent_window,
+		    EphyTab *previous_tab,
+		    const char *url,
+		    EphyNewTabFlags flags)
+{
+	return ephy_shell_new_tab_full (shell, parent_window,
+					previous_tab, url, flags,
+					EPHY_EMBED_CHROME_ALL, 0);
+}
+
 /**
  * ephy_shell_get_session:
  * @shell: the #EphyShell
@@ -627,13 +784,12 @@ ephy_shell_get_session (EphyShell *shell)
 	{
 		EphyExtensionsManager *manager;
 
+		shell->priv->session = g_object_new (EPHY_TYPE_SESSION, NULL);
+
 		manager = EPHY_EXTENSIONS_MANAGER
 			(ephy_shell_get_extensions_manager (shell));
-
-		/* Instantiate internal extensions */
-		shell->priv->session =
-			EPHY_SESSION (ephy_extensions_manager_add
-				(manager, EPHY_TYPE_SESSION));
+		ephy_extensions_manager_register (manager,
+						  G_OBJECT (shell->priv->session));
 	}
 
 	return G_OBJECT (shell->priv->session);
@@ -653,7 +809,7 @@ ephy_shell_get_bookmarks (EphyShell *shell)
 GObject *
 ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 {
-	LOG ("ephy_shell_get_toolbars_model fs=%d", fullscreen)
+	LOG ("ephy_shell_get_toolbars_model fs=%d", fullscreen);
 
 	if (fullscreen)
 	{
@@ -705,19 +861,11 @@ ephy_shell_get_extensions_manager (EphyShell *es)
 
 	if (es->priv->extensions_manager == NULL)
 	{
-		char *path;
-
 		/* Instantiate extensions manager */
-		es->priv->extensions_manager = ephy_extensions_manager_new ();
+		es->priv->extensions_manager =
+			g_object_new (EPHY_TYPE_EXTENSIONS_MANAGER, NULL);
 
-		/* load the extensions */
-		ephy_extensions_manager_load_dir (es->priv->extensions_manager,
-						  EXTENSIONS_DIR);
-
-		path = g_build_filename (ephy_dot_dir (), "extensions", NULL);
-		ephy_extensions_manager_load_dir (es->priv->extensions_manager,
-						  path);
-		g_free (path);
+		ephy_extensions_manager_startup (es->priv->extensions_manager);
 	}
 
 	return G_OBJECT (es->priv->extensions_manager);
@@ -728,7 +876,7 @@ toolwindow_show_cb (GtkWidget *widget, EphyShell *es)
 {
 	EphySession *session;
 
-	LOG ("Ref shell for %s", G_OBJECT_TYPE_NAME (widget))
+	LOG ("Ref shell for %s", G_OBJECT_TYPE_NAME (widget));
 
 	session = EPHY_SESSION (ephy_shell_get_session (es));
 	ephy_session_add_window (ephy_shell->priv->session, GTK_WINDOW (widget));
@@ -740,7 +888,7 @@ toolwindow_hide_cb (GtkWidget *widget, EphyShell *es)
 {
 	EphySession *session;
 
-	LOG ("Unref shell for %s", G_OBJECT_TYPE_NAME (widget))
+	LOG ("Unref shell for %s", G_OBJECT_TYPE_NAME (widget));
 
 	session = EPHY_SESSION (ephy_shell_get_session (es));
 	ephy_session_remove_window (ephy_shell->priv->session, GTK_WINDOW (widget));
@@ -829,3 +977,19 @@ ephy_shell_get_print_setup_dialog (EphyShell *shell)
 
 	return shell->priv->print_setup_dialog;
 }
+
+#ifdef ENABLE_DBUS
+GObject	*
+ephy_shell_get_dbus_service (EphyShell *shell)
+{
+	g_return_val_if_fail (EPHY_IS_SHELL (shell), NULL);
+
+	if (shell->priv->dbus_service == NULL)
+	{
+		shell->priv->dbus_service = g_object_new (EPHY_TYPE_DBUS, NULL);
+		ephy_dbus_startup (EPHY_DBUS (shell->priv->dbus_service));
+	}
+
+	return G_OBJECT (shell->priv->dbus_service);
+}
+#endif
