@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.269 2005/02/02 19:53:26 chpe Exp $
+ *  $Id: ephy-window.c,v 1.272 2005/02/24 15:00:17 chpe Exp $
  */
 
 #include "config.h"
@@ -463,34 +463,6 @@ destroy_fullscreen_popup (EphyWindow *window)
 	}
 }
 
-static void
-ephy_window_destroy (GtkObject *gtkobject)
-{
-	EphyWindow *window = EPHY_WINDOW (gtkobject);
-	GSList *popups;
-
-	LOG ("EphyWindow destroy %p", window);
-
-	if (window->priv->closing == FALSE)
-	{
-		EphyExtension *manager;
-
-		window->priv->closing = TRUE;
-
-		/* Let the extensions detach themselves from the window */
-		manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
-		ephy_extension_detach_window (manager, window);
-	}
-
-	destroy_fullscreen_popup (window);
-
-	popups = gtk_ui_manager_get_toplevels (window->priv->manager, GTK_UI_MANAGER_POPUP);
-	g_slist_foreach (popups, (GFunc) gtk_menu_shell_deactivate, NULL);
-	g_slist_free (popups);
-
-        GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
-}
-
 static void
 add_widget (GtkUIManager *manager,
 	    GtkWidget *widget,
@@ -1844,7 +1816,6 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 {
 	EphyTab *old_tab;
 	EphyEmbed *embed;
-	GtkToggleAction *action;
 
 	g_return_if_fail (EPHY_IS_WINDOW (window));
 	g_return_if_fail (gtk_widget_get_toplevel (GTK_WIDGET (new_tab)) == GTK_WIDGET (window));
@@ -1853,7 +1824,7 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 
 	if (old_tab == new_tab) return;
 
-	if (old_tab)
+	if (old_tab != NULL)
 	{
 		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
 						      G_CALLBACK (sync_tab_address),
@@ -1896,14 +1867,11 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 		g_signal_handlers_disconnect_by_func (G_OBJECT (embed),
 						      G_CALLBACK (tab_context_menu_cb),
 						      window);
-
-		action = GTK_TOGGLE_ACTION (ephy_tab_get_action (old_tab));
-		gtk_toggle_action_set_active (action, FALSE);
 	}
 
 	window->priv->active_tab = new_tab;
 
-	if (new_tab)
+	if (new_tab != NULL)
 	{
 		sync_tab_address	(new_tab, NULL, window);
 		sync_tab_document_type	(new_tab, NULL, window);
@@ -1972,9 +1940,6 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 					 G_CALLBACK (tab_context_menu_cb),
 					 window, G_CONNECT_AFTER);
 
-		action = GTK_TOGGLE_ACTION (ephy_tab_get_action (new_tab));
-		gtk_toggle_action_set_active (action, TRUE);
-
 		g_object_notify (G_OBJECT (window), "active-tab");
 	}
 }
@@ -2014,12 +1979,16 @@ static gboolean
 modal_alert_cb (EphyEmbed *embed,
 		EphyWindow *window)
 {
+	EphyWindowPrivate *priv = window->priv;
 	EphyTab *tab;
 	char *address;
 
 	tab = ephy_tab_for_embed (embed);
 	g_return_val_if_fail (tab != NULL, FALSE);
 
+	/* if we're in ppv mode, we cannot switch tabs, so inhibit the alert */
+	if (priv->ppv_mode) return TRUE;
+
 	/* switch the window to the tab, and bring the window to the foreground
 	 * (since the alert is modal, the user won't be able to do anything
 	 * with his current window anyway :|)
@@ -2029,7 +1998,7 @@ modal_alert_cb (EphyEmbed *embed,
 
 	/* make sure the location entry shows the real URL of the tab's page */
 	address = ephy_embed_get_location (embed, TRUE);
-	ephy_toolbar_set_location (window->priv->toolbar, address);
+	ephy_toolbar_set_location (priv->toolbar, address);
 	g_free (address);
 
 	/* don't suppress alert */
@@ -2115,6 +2084,9 @@ tab_added_cb (EphyNotebook *notebook,
 
 	g_signal_connect_object (G_OBJECT (tab), "notify::visibility",
 				 G_CALLBACK (sync_tab_visibility), window, 0);
+	g_signal_connect_object (G_OBJECT (tab), "open-link",
+				 G_CALLBACK (ephy_link_open), window,
+				 G_CONNECT_SWAPPED);
 
 	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (embed != NULL);
@@ -2143,6 +2115,9 @@ tab_removed_cb (EphyNotebook *notebook,
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (tab),
 					      G_CALLBACK (sync_tab_visibility),
+					      window);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (tab),
+					      G_CALLBACK (ephy_link_open),
 					      window);	
 
 	window->priv->num_tabs--;
@@ -2273,6 +2248,83 @@ ephy_window_set_chrome (EphyWindow *window, EphyEmbedChrome mask)
 	update_chromes_actions (window);
 }
 
+static void
+ephy_window_dispose (GObject *object)
+{
+	EphyWindow *window = EPHY_WINDOW (object);
+	EphyWindowPrivate *priv = window->priv;
+	GObject *single;
+	GSList *popups;
+
+	LOG ("EphyWindow dispose %p", window);
+
+	/* Only do these once */
+	if (window->priv->closing == FALSE)
+	{
+		EphyExtension *manager;
+
+		window->priv->closing = TRUE;
+
+		/* Let the extensions detach themselves from the window */
+		manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
+		ephy_extension_detach_window (manager, window);
+
+		/* Deactivate menus */
+		popups = gtk_ui_manager_get_toplevels (window->priv->manager, GTK_UI_MANAGER_POPUP);
+		g_slist_foreach (popups, (GFunc) gtk_menu_shell_deactivate, NULL);
+		g_slist_free (popups);
+	
+		single = ephy_embed_shell_get_embed_single (embed_shell);
+		g_signal_handlers_disconnect_by_func
+			(single, G_CALLBACK (network_status_changed), window);
+	
+		eel_gconf_notification_remove (priv->disable_arbitrary_url_notifier_id);
+		eel_gconf_notification_remove (priv->disable_bookmark_editing_notifier_id);
+		eel_gconf_notification_remove (priv->disable_toolbar_editing_notifier_id);
+		eel_gconf_notification_remove (priv->disable_history_notifier_id);
+		eel_gconf_notification_remove (priv->disable_printing_notifier_id);
+		eel_gconf_notification_remove (priv->disable_print_setup_notifier_id);
+		eel_gconf_notification_remove (priv->disable_save_to_disk_notifier_id);
+		eel_gconf_notification_remove (priv->disable_command_line_notifier_id);
+		eel_gconf_notification_remove (priv->browse_with_caret_notifier_id);
+		eel_gconf_notification_remove (priv->allow_popups_notifier_id);
+
+		if (priv->find_dialog)
+		{
+			g_object_unref (G_OBJECT (priv->find_dialog));
+			priv->find_dialog = NULL;
+		}
+	
+		g_object_unref (priv->fav_menu);
+		priv->fav_menu = NULL;
+
+		g_object_unref (priv->enc_menu);
+		priv->enc_menu = NULL;
+
+		g_object_unref (priv->tabs_menu);
+		priv->tabs_menu = NULL;
+
+		g_object_unref (priv->bmk_menu);
+		priv->bmk_menu = NULL;
+	
+		if (priv->ppview_toolbar)
+		{
+			g_object_unref (priv->ppview_toolbar);
+			priv->ppview_toolbar = NULL;
+		}
+	
+		g_object_unref (priv->action_group);
+		priv->action_group = NULL;
+
+		g_object_unref (priv->manager);
+		priv->manager = NULL;
+	}
+
+	destroy_fullscreen_popup (window);
+
+        G_OBJECT_CLASS (parent_class)->dispose (object);
+}
+
 static void
 ephy_window_set_property (GObject *object,
 			  guint prop_id,
@@ -2357,17 +2409,15 @@ static void
 ephy_window_class_init (EphyWindowClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
         parent_class = g_type_class_peek_parent (klass);
 
+	object_class->dispose = ephy_window_dispose;
         object_class->finalize = ephy_window_finalize;
 	object_class->get_property = ephy_window_get_property;
 	object_class->set_property = ephy_window_set_property;
 
-	gtkobject_class->destroy = ephy_window_destroy;
-
 	widget_class->show = ephy_window_show;
 	widget_class->key_press_event = ephy_window_key_press_event;
 	widget_class->focus_in_event = ephy_window_focus_in_event;
@@ -2485,6 +2535,9 @@ ephy_window_open_link (EphyLink *link,
 
 	g_return_val_if_fail (address != NULL, NULL);
 
+	/* don't do anything in ppv mode */
+	if (window->priv->ppv_mode) return NULL;
+
 	if (tab == NULL)
 	{
 		tab = ephy_window_get_active_tab (window);
@@ -2705,45 +2758,9 @@ ephy_window_init (EphyWindow *window)
 static void
 ephy_window_finalize (GObject *object)
 {
-        EphyWindow *window = EPHY_WINDOW (object);
-	GObject *single;
-
-	single = ephy_embed_shell_get_embed_single (embed_shell);
-	g_signal_handlers_disconnect_by_func
-		(single, G_CALLBACK (network_status_changed), window);
-
-	eel_gconf_notification_remove (window->priv->disable_arbitrary_url_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_bookmark_editing_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_toolbar_editing_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_history_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_printing_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_print_setup_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_save_to_disk_notifier_id);
-	eel_gconf_notification_remove (window->priv->disable_command_line_notifier_id);
-	eel_gconf_notification_remove (window->priv->browse_with_caret_notifier_id);
-	eel_gconf_notification_remove (window->priv->allow_popups_notifier_id);
-
-	if (window->priv->find_dialog)
-	{
-		g_object_unref (G_OBJECT (window->priv->find_dialog));
-	}
-
-	g_object_unref (window->priv->fav_menu);
-	g_object_unref (window->priv->enc_menu);
-	g_object_unref (window->priv->tabs_menu);
-	g_object_unref (window->priv->bmk_menu);
-
-	if (window->priv->ppview_toolbar)
-	{
-		g_object_unref (window->priv->ppview_toolbar);
-	}
-
-	g_object_unref (window->priv->action_group);
-	g_object_unref (window->priv->manager);
-
         G_OBJECT_CLASS (parent_class)->finalize (object);
 
-	LOG ("Ephy Window finalized %p", window);
+	LOG ("Ephy Window finalized %p", object);
 
 	g_object_unref (ephy_shell);
 }
@@ -3085,7 +3102,7 @@ ephy_window_get_active_embed (EphyWindow *window)
 	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
 
 	tab = ephy_window_get_active_tab (window);
-	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
+	if (tab == NULL) return NULL;
 
 	return ephy_tab_get_embed (tab);
 }
