@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.106 2005/01/08 16:32:09 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.108 2005/01/30 20:09:58 chpe Exp $
  */
 
 #include "config.h"
@@ -688,7 +688,7 @@ fonts_language_changed_cb (EphyDialog *dialog,
 
 	code = g_value_get_string (value);
 
-	LOG ("fonts language combo changed, new code '%s'", code)
+	LOG ("fonts language combo changed, new code '%s'", code);
 
 	setup_font_combo (dialog, "variable", code, VARIABLE_PROP);
 	setup_font_combo (dialog, "monospace", code, MONOSPACE_PROP);
@@ -1176,7 +1176,7 @@ language_editor_add_button_clicked_cb (GtkWidget *button,
 
 		g_object_add_weak_pointer
 			(G_OBJECT (pd->priv->add_lang_dialog),
-			(gpointer *) &pd->priv->add_lang_dialog);;
+			(gpointer *) &pd->priv->add_lang_dialog);
 	}
 
 	ephy_dialog_show (pd->priv->add_lang_dialog);
@@ -1427,7 +1427,7 @@ create_language_section (EphyDialog *dialog)
 }
 
 static char*
-get_download_button_label ()
+get_download_button_label (void)
 {
 	char *key, *label, *downloads_path, *converted_dp;
 
